Module durable

Module durable 

Durable execution contexts for local development and production engines.

LocalDurableContext is a passthrough implementation for local dev/testing that calls the provider and tools directly without journaling.

For production durable execution (Temporal, Restate, Inngest), see the documentation at the bottom of this module for how to implement DurableContext with those SDKs.

Structs

LocalDurableContext
A passthrough durable context for local development and testing.